@@ -55,5 +55,4 @@ $def->domain_axis->tick_values([qw(2 4 6 8 10)]);
 $def->domain_axis->format('%d');
 $def->domain_axis->fudge_amount(.05);
 
-$cc->draw;
-$cc->write('foo.png');
+$cc->write_output('foo.png');
